"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pay_schedule_assignment_department import (
    PayScheduleAssignmentDepartment,
    PayScheduleAssignmentDepartmentTypedDict,
)
from .pay_schedule_assignment_employee import (
    PayScheduleAssignmentEmployee,
    PayScheduleAssignmentEmployeeTypedDict,
)
from enum import Enum
from gusto_app_integration.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List
from typing_extensions import NotRequired, TypedDict


class Type(str, Enum):
    r"""The pay schedule assignment type."""

    SINGLE = "single"
    HOURLY_SALARIED = "hourly_salaried"
    BY_EMPLOYEE = "by_employee"
    BY_DEPARTMENT = "by_department"


class PayScheduleAssignmentTypedDict(TypedDict):
    r"""The representation of a pay schedule assignment."""

    type: NotRequired[Nullable[Type]]
    r"""The pay schedule assignment type."""
    hourly_pay_schedule_uuid: NotRequired[Nullable[str]]
    r"""Pay schedule for hourly employees."""
    salaried_pay_schedule_uuid: NotRequired[Nullable[str]]
    r"""Pay schedule for salaried employees."""
    default_pay_schedule_uuid: NotRequired[Nullable[str]]
    r"""Default pay schedule for employees."""
    employees: NotRequired[Nullable[List[PayScheduleAssignmentEmployeeTypedDict]]]
    r"""List of employees and their pay schedules."""
    departments: NotRequired[Nullable[List[PayScheduleAssignmentDepartmentTypedDict]]]
    r"""List of departments and their pay schedules."""


class PayScheduleAssignment(BaseModel):
    r"""The representation of a pay schedule assignment."""

    type: OptionalNullable[Type] = UNSET
    r"""The pay schedule assignment type."""

    hourly_pay_schedule_uuid: OptionalNullable[str] = UNSET
    r"""Pay schedule for hourly employees."""

    salaried_pay_schedule_uuid: OptionalNullable[str] = UNSET
    r"""Pay schedule for salaried employees."""

    default_pay_schedule_uuid: OptionalNullable[str] = UNSET
    r"""Default pay schedule for employees."""

    employees: OptionalNullable[List[PayScheduleAssignmentEmployee]] = UNSET
    r"""List of employees and their pay schedules."""

    departments: OptionalNullable[List[PayScheduleAssignmentDepartment]] = UNSET
    r"""List of departments and their pay schedules."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "type",
            "hourly_pay_schedule_uuid",
            "salaried_pay_schedule_uuid",
            "default_pay_schedule_uuid",
            "employees",
            "departments",
        ]
        nullable_fields = [
            "type",
            "hourly_pay_schedule_uuid",
            "salaried_pay_schedule_uuid",
            "default_pay_schedule_uuid",
            "employees",
            "departments",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
