"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_app_integration.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PayScheduleAssignmentDepartmentTypedDict(TypedDict):
    department_uuid: NotRequired[str]
    r"""The UUID of the department."""
    pay_schedule_uuid: NotRequired[str]
    r"""The department's pay schedule UUID."""


class PayScheduleAssignmentDepartment(BaseModel):
    department_uuid: Optional[str] = None
    r"""The UUID of the department."""

    pay_schedule_uuid: Optional[str] = None
    r"""The department's pay schedule UUID."""
