"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .accruing_time_off_hour import AccruingTimeOffHour, AccruingTimeOffHourTypedDict
from gusto_app_integration.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class AccruingTimeOffHourObjectTypedDict(TypedDict):
    r"""Example response"""

    hours_earned: List[AccruingTimeOffHourTypedDict]


class AccruingTimeOffHourObject(BaseModel):
    r"""Example response"""

    hours_earned: List[AccruingTimeOffHour]
