"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class OffCycleReasonType(str, Enum):
    r"""The off-cycle reason. Only included for off-cycle payrolls."""

    BENEFIT_REVERSAL = "Benefit reversal"
    BONUS = "Bonus"
    CORRECTION = "Correction"
    DISMISSED_EMPLOYEE = "Dismissed employee"
    HIRED_EMPLOYEE = "Hired employee"
    WAGE_CORRECTION = "Wage correction"
    TAX_RECONCILIATION = "Tax reconciliation"
    REVERSAL = "Reversal"
    DISABILITY_INSURANCE_DISTRIBUTION = "Disability insurance distribution"
    TRANSITION_FROM_OLD_PAY_SCHEDULE = "Transition from old pay schedule"
