"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .company_custom_field import CompanyCustomField, CompanyCustomFieldTypedDict
from gusto_app_integration.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class CompanyCustomFieldListTypedDict(TypedDict):
    r"""Example response"""

    custom_fields: NotRequired[List[CompanyCustomFieldTypedDict]]


class CompanyCustomFieldList(BaseModel):
    r"""Example response"""

    custom_fields: Optional[List[CompanyCustomField]] = None
