"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "gusto_app_integration"
__version__: str = "0.2.3"
__openapi_doc_version__: str = "2024-04-01"
__gen_version__: str = "2.562.3"
__user_agent__: str = (
    "speakeasy-sdk/python 0.2.3 2.562.3 2024-04-01 gusto_app_integration"
)

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass
